@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -52,8 +52,12 @@ namespace TheSeer\Autoload {
         public function run() {
             $result = $this->runCollector();
             if (!$result->hasUnits()) {
-                throw new ApplicationException("No units were found - process aborted.", ApplicationException::NoUnitsFound);
+                throw new ApplicationException('No units were found - process aborted.', ApplicationException::NoUnitsFound);
             }
+            if ($result->hasDuplicates()) {
+                return $this->showDuplicatesError($result->getDuplicates());
+            }
+
             if ($this->config->isCacheEnabled()) {
                 $this->factory->getCache()->persist($this->config->getCacheFile());
             }
@@ -111,7 +115,7 @@ namespace TheSeer\Autoload {
                 $this->logger->log(
                     "Warning: Template used in phar mode did not contain required __HALT_COMPILER() call\n" .
                         "which has been added automatically. The used stub code may not work as intended.\n\n", STDERR);
-                $code .= $this->config->getLineBreak() . '__HALT_COMPILER();';
+                $code .= $this->config->getLinebreak() . '__HALT_COMPILER();';
             }
             $pharBuilder = $this->factory->getPharBuilder();
             if ($keyfile = $this->config->getPharKey()) {
@@ -130,7 +134,7 @@ namespace TheSeer\Autoload {
 
         private function loadPharSignatureKey($keyfile) {
             if (!extension_loaded('openssl')) {
-                throw new ApplicationException("Extension for OpenSSL not loaded - cannot sign phar archive - process aborted.",
+                throw new ApplicationException('Extension for OpenSSL not loaded - cannot sign phar archive - process aborted.',
                     ApplicationException::OpenSSLError);
             }
             $keydata = file_get_contents($keyfile);
@@ -161,9 +165,9 @@ namespace TheSeer\Autoload {
          */
         protected function runLint($code) {
             $dsp = array(
-                0 => array("pipe", "r"),
-                1 => array("pipe", "w"),
-                2 => array("pipe", "w")
+                0 => array('pipe', 'r'),
+                1 => array('pipe', 'w'),
+                2 => array('pipe', 'w')
             );
 
             $binary = $this->config->getPhp();
@@ -195,6 +199,34 @@ namespace TheSeer\Autoload {
             return CLI::RC_OK;
         }
 
+        /**
+         * @param array $duplicates
+         *
+         * @return int
+         */
+        private function showDuplicatesError(array $duplicates) {
+            $this->logger->log(
+                sprintf("\nMultiple declarations of trait(s), interface(s) or class(es). Could not generate autoload map.\n"),
+                STDERR
+            );
+            foreach($duplicates as $unit => $files) {
+                $this->logger->log(
+                    sprintf("\nUnit '%s' defined in:\n", $unit),
+                    STDERR
+                );
+
+                /** @var array $files */
+                foreach($files as $file) {
+                    $this->logger->log(
+                        sprintf(" - %s\n", $file),
+                        STDERR
+                    );
+
+                }
+            }
+            return CLI::RC_DUPLICATES_ERROR;
+        }
+
     }
 
     class ApplicationException extends \Exception {
