@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -193,7 +193,7 @@ namespace TheSeer\Autoload {
          * @throws AutoloadBuilderException
          */
         public function setTimestamp($time) {
-            if (!is_int($time) && !is_null($time)) {
+            if (!is_int($time) && null !== $time) {
                 throw new AutoloadBuilderException("'$time' is not a unix timestamp", AutoloadBuilderException::InvalidTimestamp);
             }
             $this->timestamp = $time;
