@@ -1,7 +1,7 @@
 <?php
 
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -38,8 +38,6 @@
 
 namespace TheSeer\Autoload {
 
-    use TheSeer\DirectoryScanner\DirectoryScanner;
-
     /**
      * CLI interface to AutoloadRenderer / StaticRenderer
      *
@@ -52,6 +50,7 @@ namespace TheSeer\Autoload {
         const RC_EXEC_ERROR = 1;
         const RC_PARAM_ERROR = 3;
         const RC_LINT_ERROR = 4;
+        const RC_DUPLICATES_ERROR = 5;
 
         private $pharOption;
         private $helpOption;
@@ -119,7 +118,7 @@ namespace TheSeer\Autoload {
                         break;
                     }
                     default: {
-                       $message = "Unexpected error in collector process: " . $e->getMessage() . "\n\nPlease report this as a bug.\n\n";
+                       $message = 'Unexpected error in collector process: ' . $e->getMessage() . "\n\nPlease report this as a bug.\n\n";
                     }
                 }
                 $this->showVersion();
@@ -531,8 +530,8 @@ EOF;
             ));
 
             $input->argumentDefinition = new \ezcConsoleArguments();
-            $input->argumentDefinition[0] = new \ezcConsoleArgument( "directory" );
-            $input->argumentDefinition[0]->shorthelp = "The directory to process.";
+            $input->argumentDefinition[0] = new \ezcConsoleArgument('directory');
+            $input->argumentDefinition[0]->shorthelp = 'The directory to process.';
             $input->argumentDefinition[0]->multiple = TRUE;
 
             return $input;
