@@ -54,7 +54,7 @@ namespace TheSeer\Autoload {
 
         public function processFile(\SplFileInfo $file) {
                 try {
-                    $parseResult = $this->parser->parse(new SourceFile($file->getRealpath()));
+                    $parseResult = $this->parser->parse(new SourceFile($file->getRealPath()));
                     if ($parseResult->hasRedeclarations() && !$this->tolerantMode) {
                         throw new CollectorException(
                             sprintf(
@@ -69,8 +69,9 @@ namespace TheSeer\Autoload {
                 } catch(ParserException $e) {
                     throw new CollectorException(
                         sprintf(
-                            "Could not process file '%s' due to parse errors",
-                            $file->getRealPath()
+                            "Could not process file '%s' due to parse errors: %s",
+                            $file->getRealPath(),
+                            $e->getMessage()
                         ),
                         CollectorException::ParseErrror,
                         $e
