@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -301,6 +301,10 @@ namespace TheSeer\Autoload {
                     if (file_exists($alternative)) {
                         $template = $alternative;
                     }
+                    $alternative .= '.php.tpl';
+                    if (file_exists($alternative)) {
+                        $template = $alternative;
+                    }
                 }
                 return $template;
             }
@@ -314,6 +318,7 @@ namespace TheSeer\Autoload {
             if ($this->isPharMode()) {
                 if ($this->isStaticMode()) {
                     $tplFile = 'staticphar.php.tpl';
+                    $tplType = '.';
                 } else {
                     $tplFile = 'phar.php.tpl';
                 }
