@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -113,6 +113,7 @@ namespace TheSeer\Autoload {
             $tokList = array_keys($this->methodMap);
             for($t=0; $t<$tokenCount; $t++) {
                 $current = (array)$this->tokenArray[$t];
+
                 if ($current[0]==T_STRING && $current[1]=='trait' && T_TRAIT==-1) {
                     // PHP < 5.4 compat fix
                     $current[0] = T_TRAIT_53;
@@ -121,10 +122,7 @@ namespace TheSeer\Autoload {
                 if (!in_array($current[0], $tokList)) {
                     continue;
                 }
-                // PHP 5.5 has classname::class, reusing T_CLASS
-                if ($this->tokenArray[$t-1][0] == T_DOUBLE_COLON) {
-                    continue;
-                }
+
                 $t = call_user_func(array($this, $this->methodMap[$current[0]]), $t);
             }
             return new ParseResult($this->found, $this->dependencies, $this->redeclarations);
@@ -150,6 +148,9 @@ namespace TheSeer\Autoload {
         }
 
         private function processClass($pos) {
+            if (!$this->classTokenNeedsProcessing($pos)) {
+                return $pos;
+            }
             $list = array('{');
             $stack = $this->getTokensTill($pos, $list);
             $stackSize = count($stack);
@@ -194,7 +195,7 @@ namespace TheSeer\Autoload {
                     }
                     default: {
                         throw new ParserException(sprintf(
-                            "Parse error while trying to process class definition (unexpected token in name)."
+                            'Parse error while trying to process class definition (unexpected token in name).'
                             ), ParserException::ParseError
                         );
                     }
@@ -205,11 +206,11 @@ namespace TheSeer\Autoload {
             }
             if ($implementsFound && count($implementsList)==0) {
                 throw new ParserException(sprintf(
-                    "Parse error while trying to process class definition (extends or implements)."
+                    'Parse error while trying to process class definition (extends or implements).'
                 ), ParserException::ParseError
                 );
             }
-            $classname = $this->registerUnit($classname, $stack[0][0]);
+            $classname                      = $this->registerUnit($classname, $stack[0][0]);
             $this->dependencies[$classname] = $implementsList;
             if ($extendsFound) {
                 $this->dependencies[$classname][] = $this->resolveDependencyName($extends);
@@ -258,7 +259,7 @@ namespace TheSeer\Autoload {
         private function resolveDependencyName($name) {
             if ($name == '') {
                 throw new ParserException(sprintf(
-                    "Parse error while trying to process class definition (extends or implements)."
+                    'Parse error while trying to process class definition (extends or implements).'
                     ), ParserException::ParseError
                 );
             }
@@ -286,7 +287,7 @@ namespace TheSeer\Autoload {
         private function registerUnit($name, $type) {
             if ($name == '' || substr($name, -1) == '\\') {
                 throw new ParserException(sprintf(
-                    "Parse error while trying to process %s definition.",
+                    'Parse error while trying to process %s definition.',
                     $this->typeMap[$type]
                     ), ParserException::ParseError
                 );
@@ -461,6 +462,21 @@ namespace TheSeer\Autoload {
             }
         }
 
+        private function classTokenNeedsProcessing($position) {
+
+            // PHP 5.5 has classname::class, reusing T_CLASS
+            if ($this->tokenArray[$position-1][0] == T_DOUBLE_COLON) {
+                return false;
+            }
+
+            // PHP 7 has anonymous classes: $x = new class { ... }
+            if ($position > 2 && $this->tokenArray[$position-2][0] === T_NEW) {
+                return false;
+            }
+
+            return true;
+        }
+
     }
 
     class ParserException extends \Exception {
