@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2015 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -94,7 +94,7 @@ namespace TheSeer\Autoload {
             '___CREATED___'   => date( $this->dateformat, $this->timestamp ? $this->timestamp : time()),
             '___FILELIST___' => join( $this->linebreak . $this->indent, $entries),
             '___BASEDIR___'   => $baseDir,
-            '___AUTOLOAD___'  => uniqid('autoload')
+            '___AUTOLOAD___'  => uniqid('autoload', true)
             ));
 
             return str_replace(array_keys($replace), array_values($replace), $template);
