@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -46,7 +46,7 @@ namespace TheSeer\Autoload\Tests {
      * @author     Arne Blankerts <arne@blankerts.de>
      * @copyright  Arne Blankerts <arne@blankerts.de>, All rights reserved.
      */
-    class ParserTest extends \PHPUnit_Framework_TestCase {
+    class ParserTest extends \PHPUnit\Framework\TestCase {
 
         public function testNoClassDefined() {
             $parser = new \TheSeer\Autoload\Parser;
@@ -511,6 +511,19 @@ namespace TheSeer\Autoload\Tests {
             $this->assertEquals($units, $rc->getUnits());
             $this->assertEquals($dependencies, $rc->getDependenciesForUnit('some\\name\\space\\classd'));
         }
+
+        public function testAnonymousClassGetsIgnored() {
+            $parser = new Parser();
+            $rc = $parser->parse(new SourceFile((__DIR__.'/_data/parser/anonymousclass.php')));
+            $this->assertEmpty($rc->getUnits());
+        }
+
+        public function testAnonymousClassImplementingInterfaceGetsIgnored() {
+            $parser = new Parser();
+            $rc = $parser->parse(new SourceFile((__DIR__.'/_data/parser/anonymousclass2.php')));
+            $this->assertEquals(array('foo'), $rc->getUnits());
+        }
+
     }
 
 }
